;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "exec-path-from-shell" "20260423.1833"
  "Get environment variables such as $PATH from the shell."
  '((emacs "26.1"))
  :url "https://github.com/purcell/exec-path-from-shell"
  :commit "dae820da35ad46234cbca31626ffb6da7928694a"
  :revdesc "dae820da35ad"
  :keywords '("unix" "environment")
  :authors '(("Steve Purcell" . "steve@sanityinc.com"))
  :maintainers '(("Steve Purcell" . "steve@sanityinc.com")))
